"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.job import Job
from delphix.api.gateway.model.list_jobs_response import ListJobsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_jobs_response import SearchJobsResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse


class JobsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __abandon_job(
            self,
            job_id,
            **kwargs
        ):
            """Abandons a job.  # noqa: E501

            Abandoning a job means that the system will no longer track ongoing progress. The system will not attempt to stop the process in any way. The job will be moved to the ABANDONED terminal state.   # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.abandon_job(job_id, async_req=True)
            >>> result = thread.get()

            Args:
                job_id (str): The ID of the job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['job_id'] = \
                job_id
            return self.call_with_http_info(**kwargs)

        self.abandon_job = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs/{jobId}/abandon',
                'operation_id': 'abandon_job',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'job_id',
                ],
                'required': [
                    'job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'job_id',
                ]
            },
            root_map={
                'validations': {
                    ('job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'job_id':
                        (str,),
                },
                'attribute_map': {
                    'job_id': 'jobId',
                },
                'location_map': {
                    'job_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client,
            callable=__abandon_job
        )

        def __create_job_tags(
            self,
            job_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a Job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_job_tags(job_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                job_id (str): The ID of the job.
                tags_request (TagsRequest): Tags information for Job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['job_id'] = \
                job_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_job_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs/{jobId}/tags',
                'operation_id': 'create_job_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'job_id',
                    'tags_request',
                ],
                'required': [
                    'job_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'job_id',
                ]
            },
            root_map={
                'validations': {
                    ('job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'job_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'job_id': 'jobId',
                },
                'location_map': {
                    'job_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_job_tags
        )

        def __delete_job_tag(
            self,
            job_id,
            **kwargs
        ):
            """Delete tags for a Job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_job_tag(job_id, async_req=True)
            >>> result = thread.get()

            Args:
                job_id (str): The ID of the job.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['job_id'] = \
                job_id
            return self.call_with_http_info(**kwargs)

        self.delete_job_tag = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs/{jobId}/tags/delete',
                'operation_id': 'delete_job_tag',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'job_id',
                    'delete_tag',
                ],
                'required': [
                    'job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'job_id',
                ]
            },
            root_map={
                'validations': {
                    ('job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'job_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'job_id': 'jobId',
                },
                'location_map': {
                    'job_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_job_tag
        )

        def __get_job_by_id(
            self,
            job_id,
            **kwargs
        ):
            """Returns a job by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_job_by_id(job_id, async_req=True)
            >>> result = thread.get()

            Args:
                job_id (str): The ID of the job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Job
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['job_id'] = \
                job_id
            return self.call_with_http_info(**kwargs)

        self.get_job_by_id = _Endpoint(
            settings={
                'response_type': (Job,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs/{jobId}',
                'operation_id': 'get_job_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'job_id',
                ],
                'required': [
                    'job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'job_id',
                ]
            },
            root_map={
                'validations': {
                    ('job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'job_id':
                        (str,),
                },
                'attribute_map': {
                    'job_id': 'jobId',
                },
                'location_map': {
                    'job_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_job_by_id
        )

        def __get_job_tags(
            self,
            job_id,
            **kwargs
        ):
            """Get tags for a Job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_job_tags(job_id, async_req=True)
            >>> result = thread.get()

            Args:
                job_id (str): The ID of the job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['job_id'] = \
                job_id
            return self.call_with_http_info(**kwargs)

        self.get_job_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs/{jobId}/tags',
                'operation_id': 'get_job_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'job_id',
                ],
                'required': [
                    'job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'job_id',
                ]
            },
            root_map={
                'validations': {
                    ('job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'job_id':
                        (str,),
                },
                'attribute_map': {
                    'job_id': 'jobId',
                },
                'location_map': {
                    'job_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_job_tags
        )

        def __get_jobs(
            self,
            **kwargs
        ):
            """List all jobs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_jobs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional] if omitted the server will use the default value of "-start_time"
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListJobsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_jobs = _Endpoint(
            settings={
                'response_type': (ListJobsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs',
                'operation_id': 'get_jobs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "TYPE": "type",
                        "-TYPE": "-type",
                        "LOCALIZED_TYPE": "localized_type",
                        "-LOCALIZED_TYPE": "-localized_type",
                        "TARGET_ID": "target_id",
                        "-TARGET_ID": "-target_id",
                        "TARGET_NAME": "target_name",
                        "-TARGET_NAME": "-target_name",
                        "START_TIME": "start_time",
                        "-START_TIME": "-start_time",
                        "UPDATE_TIME": "update_time",
                        "-UPDATE_TIME": "-update_time",
                        "ERROR_DETAILS": "error_details",
                        "-ERROR_DETAILS": "-error_details",
                        "TRACE_ID": "trace_id",
                        "-TRACE_ID": "-trace_id",
                        "ACCOUNT_ID": "account_id",
                        "-ACCOUNT_ID": "-account_id",
                        "ACCOUNT_NAME": "account_name",
                        "-ACCOUNT_NAME": "-account_name"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_jobs
        )

        def __search_jobs(
            self,
            **kwargs
        ):
            """Search for jobs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_jobs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional] if omitted the server will use the default value of "-start_time"
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchJobsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_jobs = _Endpoint(
            settings={
                'response_type': (SearchJobsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/jobs/search',
                'operation_id': 'search_jobs',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "TYPE": "type",
                        "-TYPE": "-type",
                        "LOCALIZED_TYPE": "localized_type",
                        "-LOCALIZED_TYPE": "-localized_type",
                        "TARGET_ID": "target_id",
                        "-TARGET_ID": "-target_id",
                        "TARGET_NAME": "target_name",
                        "-TARGET_NAME": "-target_name",
                        "START_TIME": "start_time",
                        "-START_TIME": "-start_time",
                        "UPDATE_TIME": "update_time",
                        "-UPDATE_TIME": "-update_time",
                        "ERROR_DETAILS": "error_details",
                        "-ERROR_DETAILS": "-error_details",
                        "TRACE_ID": "trace_id",
                        "-TRACE_ID": "-trace_id",
                        "ACCOUNT_ID": "account_id",
                        "-ACCOUNT_ID": "-account_id",
                        "ACCOUNT_NAME": "account_name",
                        "-ACCOUNT_NAME": "-account_name"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_jobs
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.hyperscale_instance_api import HyperscaleInstanceApi  # noqa: E501


class TestHyperscaleInstanceApi(unittest.TestCase):
    """HyperscaleInstanceApi unit test stubs"""

    def setUp(self):
        self.api = HyperscaleInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_engine_to_hyperscale_instance(self):
        """Test case for add_engine_to_hyperscale_instance

        Add an engine to a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_create_hyperscale_instance_tags(self):
        """Test case for create_hyperscale_instance_tags

        Create tags for a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_instance_tags(self):
        """Test case for delete_hyperscale_instance_tags

        Delete tags for a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_get_hyperscale_instance_by_id(self):
        """Test case for get_hyperscale_instance_by_id

        Returns a Hyperscale Instance by ID.  # noqa: E501
        """
        pass

    def test_get_hyperscale_instance_tags(self):
        """Test case for get_hyperscale_instance_tags

        Get tags for a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_get_hyperscale_instances(self):
        """Test case for get_hyperscale_instances

        Returns a list of Hyperscale instances.  # noqa: E501
        """
        pass

    def test_register_hyperscale_instance(self):
        """Test case for register_hyperscale_instance

        Register a Hyperscale instance  # noqa: E501
        """
        pass

    def test_remove_engine_from_hyperscale_instance(self):
        """Test case for remove_engine_from_hyperscale_instance

        Remove an engine from a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_search_hyperscale_instances(self):
        """Test case for search_hyperscale_instances

        Search for Hyperscale instances.  # noqa: E501
        """
        pass

    def test_sync_engines_hyperscale_instance(self):
        """Test case for sync_engines_hyperscale_instance

        Sync the global object from a source engine to engines on a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_unregister_hyperscale_instance(self):
        """Test case for unregister_hyperscale_instance

        Unregister a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_update_hyperscale_instance(self):
        """Test case for update_hyperscale_instance

        Update an Hyperscale Instance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from delphix.api.gateway.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from delphix.api.gateway.model.api_classification_config import APIClassificationConfig
from delphix.api.gateway.model.ased_source_link_source_parameters import ASEDSourceLinkSourceParameters
from delphix.api.gateway.model.ased_source_link_source_parameters_all_of import ASEDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.access_group import AccessGroup
from delphix.api.gateway.model.access_group_account_ids_request import AccessGroupAccountIdsRequest
from delphix.api.gateway.model.access_group_scope import AccessGroupScope
from delphix.api.gateway.model.access_group_scopes_request import AccessGroupScopesRequest
from delphix.api.gateway.model.access_group_update_parameters import AccessGroupUpdateParameters
from delphix.api.gateway.model.account import Account
from delphix.api.gateway.model.account_create_parameter import AccountCreateParameter
from delphix.api.gateway.model.account_create_response import AccountCreateResponse
from delphix.api.gateway.model.account_login_parameter import AccountLoginParameter
from delphix.api.gateway.model.account_update_parameter import AccountUpdateParameter
from delphix.api.gateway.model.add_engine_to_hyperscale_response import AddEngineToHyperscaleResponse
from delphix.api.gateway.model.add_engine_to_job_response import AddEngineToJobResponse
from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
from delphix.api.gateway.model.algorithm import Algorithm
from delphix.api.gateway.model.algorithm_create_parameters import AlgorithmCreateParameters
from delphix.api.gateway.model.algorithm_revision import AlgorithmRevision
from delphix.api.gateway.model.algorithm_revision_create_parameters import AlgorithmRevisionCreateParameters
from delphix.api.gateway.model.algorithm_revision_origin_engine import AlgorithmRevisionOriginEngine
from delphix.api.gateway.model.all_object_permissions_response import AllObjectPermissionsResponse
from delphix.api.gateway.model.always_allowed_permission import AlwaysAllowedPermission
from delphix.api.gateway.model.always_allowed_permission_request import AlwaysAllowedPermissionRequest
from delphix.api.gateway.model.api_classification_object import ApiClassificationObject
from delphix.api.gateway.model.api_usage_data import ApiUsageData
from delphix.api.gateway.model.api_usage_report_response import ApiUsageReportResponse
from delphix.api.gateway.model.app_data_d_source_link_source_parameters import AppDataDSourceLinkSourceParameters
from delphix.api.gateway.model.app_data_d_source_link_source_parameters_all_of import AppDataDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.audit_logs_summary import AuditLogsSummary
from delphix.api.gateway.model.audit_logs_summary_report_response import AuditLogsSummaryReportResponse
from delphix.api.gateway.model.audit_logs_summary_totals import AuditLogsSummaryTotals
from delphix.api.gateway.model.base_d_source_link_source_parameters import BaseDSourceLinkSourceParameters
from delphix.api.gateway.model.base_provision_vdb_parameters import BaseProvisionVDBParameters
from delphix.api.gateway.model.base_provision_vdb_parameters_all_of import BaseProvisionVDBParametersAllOf
from delphix.api.gateway.model.bookmark import Bookmark
from delphix.api.gateway.model.bookmark_compatible_environments_response import BookmarkCompatibleEnvironmentsResponse
from delphix.api.gateway.model.bookmark_compatible_repository_request import BookmarkCompatibleRepositoryRequest
from delphix.api.gateway.model.bookmark_create_parameters import BookmarkCreateParameters
from delphix.api.gateway.model.cdb import CDB
from delphix.api.gateway.model.change_password_parameter import ChangePasswordParameter
from delphix.api.gateway.model.cleanup_execution_response import CleanupExecutionResponse
from delphix.api.gateway.model.cluster_node_instance import ClusterNodeInstance
from delphix.api.gateway.model.config_settings_stg import ConfigSettingsStg
from delphix.api.gateway.model.connectivity_check_parameters import ConnectivityCheckParameters
from delphix.api.gateway.model.connectivity_check_response import ConnectivityCheckResponse
from delphix.api.gateway.model.connector import Connector
from delphix.api.gateway.model.connector_test_response import ConnectorTestResponse
from delphix.api.gateway.model.connector_update_parameters import ConnectorUpdateParameters
from delphix.api.gateway.model.copy_masking_job_parameters import CopyMaskingJobParameters
from delphix.api.gateway.model.copy_masking_job_response import CopyMaskingJobResponse
from delphix.api.gateway.model.create_algorithm_response import CreateAlgorithmResponse
from delphix.api.gateway.model.create_algorithm_revision_response import CreateAlgorithmRevisionResponse
from delphix.api.gateway.model.create_bookmark_response import CreateBookmarkResponse
from delphix.api.gateway.model.create_database_template_response import CreateDatabaseTemplateResponse
from delphix.api.gateway.model.create_environment_response import CreateEnvironmentResponse
from delphix.api.gateway.model.create_environment_user_response import CreateEnvironmentUserResponse
from delphix.api.gateway.model.create_host_response import CreateHostResponse
from delphix.api.gateway.model.create_hyperscale_connector_response import CreateHyperscaleConnectorResponse
from delphix.api.gateway.model.create_hyperscale_mount_point_response import CreateHyperscaleMountPointResponse
from delphix.api.gateway.model.create_masking_job_request import CreateMaskingJobRequest
from delphix.api.gateway.model.create_masking_job_response import CreateMaskingJobResponse
from delphix.api.gateway.model.create_role import CreateRole
from delphix.api.gateway.model.create_vdb_group_request import CreateVDBGroupRequest
from delphix.api.gateway.model.create_vdb_group_response import CreateVDBGroupResponse
from delphix.api.gateway.model.credentials_env_variable import CredentialsEnvVariable
from delphix.api.gateway.model.d_source import DSource
from delphix.api.gateway.model.d_source_consumption_data import DSourceConsumptionData
from delphix.api.gateway.model.d_source_consumption_report_response import DSourceConsumptionReportResponse
from delphix.api.gateway.model.d_source_hooks import DSourceHooks
from delphix.api.gateway.model.d_source_snapshot_parameters import DSourceSnapshotParameters
from delphix.api.gateway.model.d_source_usage_data import DSourceUsageData
from delphix.api.gateway.model.d_source_usage_report_response import DSourceUsageReportResponse
from delphix.api.gateway.model.data_point_by_location_parameters import DataPointByLocationParameters
from delphix.api.gateway.model.data_point_by_snapshot_parameters import DataPointBySnapshotParameters
from delphix.api.gateway.model.data_point_by_timestamp_parameters import DataPointByTimestampParameters
from delphix.api.gateway.model.data_point_from_bookmark_parameters import DataPointFromBookmarkParameters
from delphix.api.gateway.model.database_connectivity_check_parameters import DatabaseConnectivityCheckParameters
from delphix.api.gateway.model.database_template import DatabaseTemplate
from delphix.api.gateway.model.database_template_create_parameters import DatabaseTemplateCreateParameters
from delphix.api.gateway.model.dataset_group import DatasetGroup
from delphix.api.gateway.model.delete_algorithm_response import DeleteAlgorithmResponse
from delphix.api.gateway.model.delete_algorithm_revision_response import DeleteAlgorithmRevisionResponse
from delphix.api.gateway.model.delete_d_source_request import DeleteDSourceRequest
from delphix.api.gateway.model.delete_database_template_response import DeleteDatabaseTemplateResponse
from delphix.api.gateway.model.delete_engine_response import DeleteEngineResponse
from delphix.api.gateway.model.delete_environment_response import DeleteEnvironmentResponse
from delphix.api.gateway.model.delete_environment_user_response import DeleteEnvironmentUserResponse
from delphix.api.gateway.model.delete_host_response import DeleteHostResponse
from delphix.api.gateway.model.delete_hyperscale_connector_response import DeleteHyperscaleConnectorResponse
from delphix.api.gateway.model.delete_hyperscale_mount_point_response import DeleteHyperscaleMountPointResponse
from delphix.api.gateway.model.delete_masking_job_response import DeleteMaskingJobResponse
from delphix.api.gateway.model.delete_masking_plugin_response import DeleteMaskingPluginResponse
from delphix.api.gateway.model.delete_scope_object_tags import DeleteScopeObjectTags
from delphix.api.gateway.model.delete_scoped_object_item import DeleteScopedObjectItem
from delphix.api.gateway.model.delete_snapshot_response import DeleteSnapshotResponse
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.delete_timeflow_response import DeleteTimeflowResponse
from delphix.api.gateway.model.delete_vdb_parameters import DeleteVDBParameters
from delphix.api.gateway.model.delete_vdb_response import DeleteVDBResponse
from delphix.api.gateway.model.disable_dsource_parameters import DisableDsourceParameters
from delphix.api.gateway.model.disable_dsource_response import DisableDsourceResponse
from delphix.api.gateway.model.disable_environment_response import DisableEnvironmentResponse
from delphix.api.gateway.model.disable_vdb_parameters import DisableVDBParameters
from delphix.api.gateway.model.disable_vdb_response import DisableVDBResponse
from delphix.api.gateway.model.domain import Domain
from delphix.api.gateway.model.effective_scope import EffectiveScope
from delphix.api.gateway.model.enable_dsource_parameters import EnableDsourceParameters
from delphix.api.gateway.model.enable_dsource_response import EnableDsourceResponse
from delphix.api.gateway.model.enable_environment_response import EnableEnvironmentResponse
from delphix.api.gateway.model.enable_scale_testing_request import EnableScaleTestingRequest
from delphix.api.gateway.model.enable_vdb_parameters import EnableVDBParameters
from delphix.api.gateway.model.enable_vdb_response import EnableVDBResponse
from delphix.api.gateway.model.engine import Engine
from delphix.api.gateway.model.engine_id_body import EngineIdBody
from delphix.api.gateway.model.engine_performance_analytic import EnginePerformanceAnalytic
from delphix.api.gateway.model.engine_performance_analytic_report_response import EnginePerformanceAnalyticReportResponse
from delphix.api.gateway.model.engine_performance_analytic_trend import EnginePerformanceAnalyticTrend
from delphix.api.gateway.model.engine_performance_analytic_trend_datapoint import EnginePerformanceAnalyticTrendDatapoint
from delphix.api.gateway.model.engine_performance_analytic_trend_response import EnginePerformanceAnalyticTrendResponse
from delphix.api.gateway.model.engine_registration_parameter import EngineRegistrationParameter
from delphix.api.gateway.model.environment import Environment
from delphix.api.gateway.model.environment_create_parameters import EnvironmentCreateParameters
from delphix.api.gateway.model.environment_repository import EnvironmentRepository
from delphix.api.gateway.model.environment_repository_all_of import EnvironmentRepositoryAllOf
from delphix.api.gateway.model.environment_update_parameters import EnvironmentUpdateParameters
from delphix.api.gateway.model.environment_user import EnvironmentUser
from delphix.api.gateway.model.environment_user_params import EnvironmentUserParams
from delphix.api.gateway.model.error import Error
from delphix.api.gateway.model.error_response import ErrorResponse
from delphix.api.gateway.model.errors import Errors
from delphix.api.gateway.model.execute_masking_job_parameters import ExecuteMaskingJobParameters
from delphix.api.gateway.model.execute_masking_job_response import ExecuteMaskingJobResponse
from delphix.api.gateway.model.execution import Execution
from delphix.api.gateway.model.execution_cancel_parameters import ExecutionCancelParameters
from delphix.api.gateway.model.execution_event import ExecutionEvent
from delphix.api.gateway.model.execution_log import ExecutionLog
from delphix.api.gateway.model.find_by_location_response import FindByLocationResponse
from delphix.api.gateway.model.find_by_timestamp_response import FindByTimestampResponse
from delphix.api.gateway.model.framework import Framework
from delphix.api.gateway.model.global_properties import GlobalProperties
from delphix.api.gateway.model.hashicorp_vault import HashicorpVault
from delphix.api.gateway.model.hook import Hook
from delphix.api.gateway.model.host import Host
from delphix.api.gateway.model.host_create_parameters import HostCreateParameters
from delphix.api.gateway.model.host_update_parameters import HostUpdateParameters
from delphix.api.gateway.model.hyperscale_column_or_field import HyperscaleColumnOrField
from delphix.api.gateway.model.hyperscale_connector import HyperscaleConnector
from delphix.api.gateway.model.hyperscale_connector_update_parameters import HyperscaleConnectorUpdateParameters
from delphix.api.gateway.model.hyperscale_data_type_enum import HyperscaleDataTypeEnum
from delphix.api.gateway.model.hyperscale_dataset import HyperscaleDataset
from delphix.api.gateway.model.hyperscale_dataset_table_or_file import HyperscaleDatasetTableOrFile
from delphix.api.gateway.model.hyperscale_dataset_table_or_file_update_parameters import HyperscaleDatasetTableOrFileUpdateParameters
from delphix.api.gateway.model.hyperscale_dataset_update_parameters import HyperscaleDatasetUpdateParameters
from delphix.api.gateway.model.hyperscale_instance import HyperscaleInstance
from delphix.api.gateway.model.hyperscale_instance_registration_parameter import HyperscaleInstanceRegistrationParameter
from delphix.api.gateway.model.hyperscale_instance_update_params import HyperscaleInstanceUpdateParams
from delphix.api.gateway.model.hyperscale_mount_point import HyperscaleMountPoint
from delphix.api.gateway.model.hyperscale_mount_point_update_parameters import HyperscaleMountPointUpdateParameters
from delphix.api.gateway.model.hyperscale_task_error import HyperscaleTaskError
from delphix.api.gateway.model.hyperscale_task_event import HyperscaleTaskEvent
from delphix.api.gateway.model.install_masking_plugin_parameters import InstallMaskingPluginParameters
from delphix.api.gateway.model.install_masking_plugin_response import InstallMaskingPluginResponse
from delphix.api.gateway.model.job import Job
from delphix.api.gateway.model.kdc_servers import KDCServers
from delphix.api.gateway.model.kerberos_config import KerberosConfig
from delphix.api.gateway.model.ldap_config_params import LDAPConfigParams
from delphix.api.gateway.model.ldap_config_validate_parameter import LdapConfigValidateParameter
from delphix.api.gateway.model.ldap_validate_response import LdapValidateResponse
from delphix.api.gateway.model.link_d_source_default_request import LinkDSourceDefaultRequest
from delphix.api.gateway.model.link_d_source_response import LinkDSourceResponse
from delphix.api.gateway.model.link_staging_push_d_source_default_request import LinkStagingPushDSourceDefaultRequest
from delphix.api.gateway.model.list_access_groups_response import ListAccessGroupsResponse
from delphix.api.gateway.model.list_accounts_response import ListAccountsResponse
from delphix.api.gateway.model.list_algorithm_revisions_response import ListAlgorithmRevisionsResponse
from delphix.api.gateway.model.list_algorithms_response import ListAlgorithmsResponse
from delphix.api.gateway.model.list_bookmarks_by_vdb_groups_response import ListBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.list_bookmarks_by_vdb_response import ListBookmarksByVDBResponse
from delphix.api.gateway.model.list_bookmarks_response import ListBookmarksResponse
from delphix.api.gateway.model.list_cdbs_response import ListCDBsResponse
from delphix.api.gateway.model.list_connectors_response import ListConnectorsResponse
from delphix.api.gateway.model.list_d_sources_response import ListDSourcesResponse
from delphix.api.gateway.model.list_database_templates_response import ListDatabaseTemplatesResponse
from delphix.api.gateway.model.list_environment_users import ListEnvironmentUsers
from delphix.api.gateway.model.list_environments_response import ListEnvironmentsResponse
from delphix.api.gateway.model.list_execution_events_response import ListExecutionEventsResponse
from delphix.api.gateway.model.list_executions_response import ListExecutionsResponse
from delphix.api.gateway.model.list_groups_response import ListGroupsResponse
from delphix.api.gateway.model.list_hashicorp_vaults_response import ListHashicorpVaultsResponse
from delphix.api.gateway.model.list_hyperscale_connectors_response import ListHyperscaleConnectorsResponse
from delphix.api.gateway.model.list_hyperscale_dataset_tables_or_files_response import ListHyperscaleDatasetTablesOrFilesResponse
from delphix.api.gateway.model.list_hyperscale_datasets_response import ListHyperscaleDatasetsResponse
from delphix.api.gateway.model.list_hyperscale_instances_response import ListHyperscaleInstancesResponse
from delphix.api.gateway.model.list_hyperscale_mount_points_response import ListHyperscaleMountPointsResponse
from delphix.api.gateway.model.list_jobs_response import ListJobsResponse
from delphix.api.gateway.model.list_kerberos_configs_response import ListKerberosConfigsResponse
from delphix.api.gateway.model.list_masking_environments_response import ListMaskingEnvironmentsResponse
from delphix.api.gateway.model.list_masking_job_source_engines_response import ListMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.list_masking_jobs_response import ListMaskingJobsResponse
from delphix.api.gateway.model.list_masking_plugins_response import ListMaskingPluginsResponse
from delphix.api.gateway.model.list_password_vaults_response import ListPasswordVaultsResponse
from delphix.api.gateway.model.list_registered_engines_response import ListRegisteredEnginesResponse
from delphix.api.gateway.model.list_replication_profiles_response import ListReplicationProfilesResponse
from delphix.api.gateway.model.list_reporting_schedule_response import ListReportingScheduleResponse
from delphix.api.gateway.model.list_roles_response import ListRolesResponse
from delphix.api.gateway.model.list_snapshots_response import ListSnapshotsResponse
from delphix.api.gateway.model.list_sources_response import ListSourcesResponse
from delphix.api.gateway.model.list_staging_sources_response import ListStagingSourcesResponse
from delphix.api.gateway.model.list_timeflows_response import ListTimeflowsResponse
from delphix.api.gateway.model.list_toolkit_response import ListToolkitResponse
from delphix.api.gateway.model.list_vcdbs_response import ListVCDBsResponse
from delphix.api.gateway.model.list_vdb_groups_by_bookmark_response import ListVDBGroupsByBookmarkResponse
from delphix.api.gateway.model.list_vdb_groups_response import ListVDBGroupsResponse
from delphix.api.gateway.model.list_vdbs_response import ListVDBsResponse
from delphix.api.gateway.model.list_virtualization_policies_response import ListVirtualizationPoliciesResponse
from delphix.api.gateway.model.location_compatible_environments_response import LocationCompatibleEnvironmentsResponse
from delphix.api.gateway.model.location_compatible_repository_request import LocationCompatibleRepositoryRequest
from delphix.api.gateway.model.lock_vdb_group_parameters import LockVDBGroupParameters
from delphix.api.gateway.model.lock_vdb_parameters import LockVDBParameters
from delphix.api.gateway.model.login_token import LoginToken
from delphix.api.gateway.model.mssqld_source_link_source_parameters import MSSQLDSourceLinkSourceParameters
from delphix.api.gateway.model.mssqld_source_link_source_parameters_all_of import MSSQLDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.mssqld_source_staging_push_link_source_parameters import MSSQLDSourceStagingPushLinkSourceParameters
from delphix.api.gateway.model.mssqld_source_staging_push_link_source_parameters_all_of import MSSQLDSourceStagingPushLinkSourceParametersAllOf
from delphix.api.gateway.model.masking_environment import MaskingEnvironment
from delphix.api.gateway.model.masking_execution_metrics import MaskingExecutionMetrics
from delphix.api.gateway.model.masking_execution_metrics_report_response import MaskingExecutionMetricsReportResponse
from delphix.api.gateway.model.masking_file_upload import MaskingFileUpload
from delphix.api.gateway.model.masking_file_upload_response import MaskingFileUploadResponse
from delphix.api.gateway.model.masking_job import MaskingJob
from delphix.api.gateway.model.masking_job_connectors_response import MaskingJobConnectorsResponse
from delphix.api.gateway.model.masking_job_source_engine import MaskingJobSourceEngine
from delphix.api.gateway.model.masking_plugin import MaskingPlugin
from delphix.api.gateway.model.masking_ruleset import MaskingRuleset
from delphix.api.gateway.model.metadata_db_info import MetadataDbInfo
from delphix.api.gateway.model.migrate_masking_job_parameters import MigrateMaskingJobParameters
from delphix.api.gateway.model.migrate_masking_job_response import MigrateMaskingJobResponse
from delphix.api.gateway.model.name_value_pair import NameValuePair
from delphix.api.gateway.model.object_permission_access_groups import ObjectPermissionAccessGroups
from delphix.api.gateway.model.object_permission_account import ObjectPermissionAccount
from delphix.api.gateway.model.object_permissions_response import ObjectPermissionsResponse
from delphix.api.gateway.model.object_type_enum import ObjectTypeEnum
from delphix.api.gateway.model.object_type_property import ObjectTypeProperty
from delphix.api.gateway.model.oracle_cluster_node_instance import OracleClusterNodeInstance
from delphix.api.gateway.model.oracle_d_source_link_source_parameters import OracleDSourceLinkSourceParameters
from delphix.api.gateway.model.oracle_d_source_link_source_parameters_all_of import OracleDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.oracle_link_staging_push_d_source_default_request import OracleLinkStagingPushDSourceDefaultRequest
from delphix.api.gateway.model.oracle_listener import OracleListener
from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
from delphix.api.gateway.model.oracle_staging_push_d_source_link_source_parameters import OracleStagingPushDSourceLinkSourceParameters
from delphix.api.gateway.model.oracle_staging_push_d_source_link_source_parameters_all_of import OracleStagingPushDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.oracle_virtual_ip import OracleVirtualIP
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
from delphix.api.gateway.model.password_policies_params import PasswordPoliciesParams
from delphix.api.gateway.model.password_vault import PasswordVault
from delphix.api.gateway.model.permission_enum import PermissionEnum
from delphix.api.gateway.model.permission_object import PermissionObject
from delphix.api.gateway.model.permission_property import PermissionProperty
from delphix.api.gateway.model.permissions_request import PermissionsRequest
from delphix.api.gateway.model.primary_environment_user_response import PrimaryEnvironmentUserResponse
from delphix.api.gateway.model.product_history import ProductHistory
from delphix.api.gateway.model.product_info import ProductInfo
from delphix.api.gateway.model.product_registration_offline_payload import ProductRegistrationOfflinePayload
from delphix.api.gateway.model.product_registration_online_payload import ProductRegistrationOnlinePayload
from delphix.api.gateway.model.provision_vdbby_location_defaults_request import ProvisionVDBByLocationDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_location_parameters import ProvisionVDBByLocationParameters
from delphix.api.gateway.model.provision_vdbby_location_parameters_all_of import ProvisionVDBByLocationParametersAllOf
from delphix.api.gateway.model.provision_vdbby_snapshot_defaults_request import ProvisionVDBBySnapshotDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters import ProvisionVDBBySnapshotParameters
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters_all_of import ProvisionVDBBySnapshotParametersAllOf
from delphix.api.gateway.model.provision_vdbby_timestamp_defaults_request import ProvisionVDBByTimestampDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters import ProvisionVDBByTimestampParameters
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters_all_of import ProvisionVDBByTimestampParametersAllOf
from delphix.api.gateway.model.provision_vdb_from_bookmark_defaults_request import ProvisionVDBFromBookmarkDefaultsRequest
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters import ProvisionVDBFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters_all_of import ProvisionVDBFromBookmarkParametersAllOf
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_parameters import ProvisionVDBGroupFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_response import ProvisionVDBGroupFromBookmarkResponse
from delphix.api.gateway.model.provision_vdb_response import ProvisionVDBResponse
from delphix.api.gateway.model.proxy_configuration import ProxyConfiguration
from delphix.api.gateway.model.re_import_masking_job_response import ReImportMaskingJobResponse
from delphix.api.gateway.model.refresh_environment_response import RefreshEnvironmentResponse
from delphix.api.gateway.model.refresh_vdbby_location_parameters import RefreshVDBByLocationParameters
from delphix.api.gateway.model.refresh_vdbby_location_response import RefreshVDBByLocationResponse
from delphix.api.gateway.model.refresh_vdbby_snapshot_parameters import RefreshVDBBySnapshotParameters
from delphix.api.gateway.model.refresh_vdbby_snapshot_response import RefreshVDBBySnapshotResponse
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters import RefreshVDBByTimestampParameters
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters_all_of import RefreshVDBByTimestampParametersAllOf
from delphix.api.gateway.model.refresh_vdbby_timestamp_response import RefreshVDBByTimestampResponse
from delphix.api.gateway.model.refresh_vdb_from_bookmark_parameters import RefreshVDBFromBookmarkParameters
from delphix.api.gateway.model.refresh_vdb_from_bookmark_response import RefreshVDBFromBookmarkResponse
from delphix.api.gateway.model.refresh_vdb_group_parameters import RefreshVDBGroupParameters
from delphix.api.gateway.model.refresh_vdb_group_response import RefreshVDBGroupResponse
from delphix.api.gateway.model.registered_engine import RegisteredEngine
from delphix.api.gateway.model.remove_engine_from_hyperscale_response import RemoveEngineFromHyperscaleResponse
from delphix.api.gateway.model.remove_engine_from_job_response import RemoveEngineFromJobResponse
from delphix.api.gateway.model.remove_masking_job_parameters import RemoveMaskingJobParameters
from delphix.api.gateway.model.replica import Replica
from delphix.api.gateway.model.replication_profile import ReplicationProfile
from delphix.api.gateway.model.reporting_schedule import ReportingSchedule
from delphix.api.gateway.model.reporting_schedule_create_parameters import ReportingScheduleCreateParameters
from delphix.api.gateway.model.repository import Repository
from delphix.api.gateway.model.reset_password_parameter import ResetPasswordParameter
from delphix.api.gateway.model.restart_execution_response import RestartExecutionResponse
from delphix.api.gateway.model.role import Role
from delphix.api.gateway.model.role_all_of import RoleAllOf
from delphix.api.gateway.model.role_update_parameters import RoleUpdateParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_parameters import RollbackVDBBySnapshotParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_response import RollbackVDBBySnapshotResponse
from delphix.api.gateway.model.rollback_vdbby_timestamp_parameters import RollbackVDBByTimestampParameters
from delphix.api.gateway.model.rollback_vdbby_timestamp_response import RollbackVDBByTimestampResponse
from delphix.api.gateway.model.rollback_vdb_from_bookmark_parameters import RollbackVDBFromBookmarkParameters
from delphix.api.gateway.model.rollback_vdb_from_bookmark_response import RollbackVDBFromBookmarkResponse
from delphix.api.gateway.model.rollback_vdb_group_parameters import RollbackVDBGroupParameters
from delphix.api.gateway.model.rollback_vdb_group_response import RollbackVDBGroupResponse
from delphix.api.gateway.model.saml_config_params import SAMLConfigParams
from delphix.api.gateway.model.smtp_config_params import SMTPConfigParams
from delphix.api.gateway.model.smtp_config_validate import SMTPConfigValidate
from delphix.api.gateway.model.ssh_verification_strategy import SSHVerificationStrategy
from delphix.api.gateway.model.scope_tag import ScopeTag
from delphix.api.gateway.model.scope_tags_request import ScopeTagsRequest
from delphix.api.gateway.model.scope_tags_response import ScopeTagsResponse
from delphix.api.gateway.model.scoped_object_item import ScopedObjectItem
from delphix.api.gateway.model.scoped_object_items_response import ScopedObjectItemsResponse
from delphix.api.gateway.model.scoped_objects_request import ScopedObjectsRequest
from delphix.api.gateway.model.search_access_groups_response import SearchAccessGroupsResponse
from delphix.api.gateway.model.search_accounts_response import SearchAccountsResponse
from delphix.api.gateway.model.search_algorithm_revisions_response import SearchAlgorithmRevisionsResponse
from delphix.api.gateway.model.search_algorithms_response import SearchAlgorithmsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_bookmarks_by_vdb_groups_response import SearchBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.search_bookmarks_by_vdb_response import SearchBookmarksByVDBResponse
from delphix.api.gateway.model.search_bookmarks_response import SearchBookmarksResponse
from delphix.api.gateway.model.search_cdbs_response import SearchCDBsResponse
from delphix.api.gateway.model.search_connectors_response import SearchConnectorsResponse
from delphix.api.gateway.model.search_d_sources_response import SearchDSourcesResponse
from delphix.api.gateway.model.search_database_templates_response import SearchDatabaseTemplatesResponse
from delphix.api.gateway.model.search_dataset_group_response import SearchDatasetGroupResponse
from delphix.api.gateway.model.search_engines_response import SearchEnginesResponse
from delphix.api.gateway.model.search_environments_response import SearchEnvironmentsResponse
from delphix.api.gateway.model.search_execution_events_response import SearchExecutionEventsResponse
from delphix.api.gateway.model.search_executions_response import SearchExecutionsResponse
from delphix.api.gateway.model.search_hashicorp_vaults_response import SearchHashicorpVaultsResponse
from delphix.api.gateway.model.search_hyperscale_connectors_response import SearchHyperscaleConnectorsResponse
from delphix.api.gateway.model.search_hyperscale_dataset_tables_or_files_response import SearchHyperscaleDatasetTablesOrFilesResponse
from delphix.api.gateway.model.search_hyperscale_datasets_response import SearchHyperscaleDatasetsResponse
from delphix.api.gateway.model.search_hyperscale_instances_response import SearchHyperscaleInstancesResponse
from delphix.api.gateway.model.search_hyperscale_mount_points_response import SearchHyperscaleMountPointsResponse
from delphix.api.gateway.model.search_jobs_response import SearchJobsResponse
from delphix.api.gateway.model.search_kerberos_configs_response import SearchKerberosConfigsResponse
from delphix.api.gateway.model.search_masking_environments_response import SearchMaskingEnvironmentsResponse
from delphix.api.gateway.model.search_masking_job_source_engines_response import SearchMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.search_masking_jobs_response import SearchMaskingJobsResponse
from delphix.api.gateway.model.search_masking_plugins_response import SearchMaskingPluginsResponse
from delphix.api.gateway.model.search_password_vault_response import SearchPasswordVaultResponse
from delphix.api.gateway.model.search_replication_profiles_response import SearchReplicationProfilesResponse
from delphix.api.gateway.model.search_reporting_schedule_response import SearchReportingScheduleResponse
from delphix.api.gateway.model.search_roles_response import SearchRolesResponse
from delphix.api.gateway.model.search_snapshots_response import SearchSnapshotsResponse
from delphix.api.gateway.model.search_sources_response import SearchSourcesResponse
from delphix.api.gateway.model.search_staging_sources_response import SearchStagingSourcesResponse
from delphix.api.gateway.model.search_timeflows_response import SearchTimeflowsResponse
from delphix.api.gateway.model.search_toolkit_response import SearchToolkitResponse
from delphix.api.gateway.model.search_vcdbs_response import SearchVCDBsResponse
from delphix.api.gateway.model.search_vdb_group_response import SearchVDBGroupResponse
from delphix.api.gateway.model.search_vdb_groups_by_bookmark_response import SearchVDBGroupsByBookmarkResponse
from delphix.api.gateway.model.search_vdbs_response import SearchVDBsResponse
from delphix.api.gateway.model.search_virtualization_policies_response import SearchVirtualizationPoliciesResponse
from delphix.api.gateway.model.set_algorithm_primary_revision_response import SetAlgorithmPrimaryRevisionResponse
from delphix.api.gateway.model.snapshot import Snapshot
from delphix.api.gateway.model.snapshot_compatible_environments_response import SnapshotCompatibleEnvironmentsResponse
from delphix.api.gateway.model.snapshot_compatible_repository_request import SnapshotCompatibleRepositoryRequest
from delphix.api.gateway.model.snapshot_d_source_response import SnapshotDSourceResponse
from delphix.api.gateway.model.snapshot_day_range import SnapshotDayRange
from delphix.api.gateway.model.snapshot_vdb_response import SnapshotVDBResponse
from delphix.api.gateway.model.snapshots_day_ranges_response import SnapshotsDayRangesResponse
from delphix.api.gateway.model.source import Source
from delphix.api.gateway.model.source_operation import SourceOperation
from delphix.api.gateway.model.staging_compatible_environments_response import StagingCompatibleEnvironmentsResponse
from delphix.api.gateway.model.staging_source import StagingSource
from delphix.api.gateway.model.start_vdb_response import StartVDBResponse
from delphix.api.gateway.model.stop_vdb_response import StopVDBResponse
from delphix.api.gateway.model.storage_savings_report_summarized_data import StorageSavingsReportSummarizedData
from delphix.api.gateway.model.storage_savings_summary_data import StorageSavingsSummaryData
from delphix.api.gateway.model.storage_savings_summary_report_response import StorageSavingsSummaryReportResponse
from delphix.api.gateway.model.switch_timeflow_parameters import SwitchTimeflowParameters
from delphix.api.gateway.model.switch_timeflow_response import SwitchTimeflowResponse
from delphix.api.gateway.model.sync_engines_hyperscale_parameters import SyncEnginesHyperscaleParameters
from delphix.api.gateway.model.sync_engines_hyperscale_response import SyncEnginesHyperscaleResponse
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.task_event import TaskEvent
from delphix.api.gateway.model.timeflow import Timeflow
from delphix.api.gateway.model.timeflow_range import TimeflowRange
from delphix.api.gateway.model.timestamp_compatible_environments_response import TimestampCompatibleEnvironmentsResponse
from delphix.api.gateway.model.timestamp_compatible_repository_request import TimestampCompatibleRepositoryRequest
from delphix.api.gateway.model.token_info_request import TokenInfoRequest
from delphix.api.gateway.model.token_info_response import TokenInfoResponse
from delphix.api.gateway.model.toolkit import Toolkit
from delphix.api.gateway.model.unregister_hyperscale_instance_response import UnregisterHyperscaleInstanceResponse
from delphix.api.gateway.model.unset_snapshot_retention_response import UnsetSnapshotRetentionResponse
from delphix.api.gateway.model.update_access_group_scope import UpdateAccessGroupScope
from delphix.api.gateway.model.update_algorithm_revision_parameters import UpdateAlgorithmRevisionParameters
from delphix.api.gateway.model.update_algorithm_revision_response import UpdateAlgorithmRevisionResponse
from delphix.api.gateway.model.update_bookmark_parameters import UpdateBookmarkParameters
from delphix.api.gateway.model.update_bookmark_response import UpdateBookmarkResponse
from delphix.api.gateway.model.update_connector_response import UpdateConnectorResponse
from delphix.api.gateway.model.update_database_template_parameters import UpdateDatabaseTemplateParameters
from delphix.api.gateway.model.update_database_template_response import UpdateDatabaseTemplateResponse
from delphix.api.gateway.model.update_environment_response import UpdateEnvironmentResponse
from delphix.api.gateway.model.update_environment_user_response import UpdateEnvironmentUserResponse
from delphix.api.gateway.model.update_host_response import UpdateHostResponse
from delphix.api.gateway.model.update_hyperscale_connector_response import UpdateHyperscaleConnectorResponse
from delphix.api.gateway.model.update_hyperscale_dataset_response import UpdateHyperscaleDatasetResponse
from delphix.api.gateway.model.update_hyperscale_dataset_table_or_file_response import UpdateHyperscaleDatasetTableOrFileResponse
from delphix.api.gateway.model.update_hyperscale_mount_point_response import UpdateHyperscaleMountPointResponse
from delphix.api.gateway.model.update_masking_job_parameters import UpdateMaskingJobParameters
from delphix.api.gateway.model.update_repository_parameters import UpdateRepositoryParameters
from delphix.api.gateway.model.update_repository_response import UpdateRepositoryResponse
from delphix.api.gateway.model.update_snapshot_parameters import UpdateSnapshotParameters
from delphix.api.gateway.model.update_snapshot_response import UpdateSnapshotResponse
from delphix.api.gateway.model.update_timeflow_parameters import UpdateTimeflowParameters
from delphix.api.gateway.model.update_timeflow_response import UpdateTimeflowResponse
from delphix.api.gateway.model.update_vdb_group_parameters import UpdateVDBGroupParameters
from delphix.api.gateway.model.update_vdb_parameters import UpdateVDBParameters
from delphix.api.gateway.model.update_vdb_response import UpdateVDBResponse
from delphix.api.gateway.model.vcdb import VCDB
from delphix.api.gateway.model.vdb import VDB
from delphix.api.gateway.model.vdb_group import VDBGroup
from delphix.api.gateway.model.vdb_inventory_data import VDBInventoryData
from delphix.api.gateway.model.vdb_inventory_report_response import VDBInventoryReportResponse
from delphix.api.gateway.model.validate_java_parameters import ValidateJavaParameters
from delphix.api.gateway.model.validate_java_response import ValidateJavaResponse
from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
from delphix.api.gateway.model.virtualization_policy import VirtualizationPolicy
from delphix.api.gateway.model.virtualization_schedule import VirtualizationSchedule
from delphix.api.gateway.model.virtualization_storage_summary_data import VirtualizationStorageSummaryData
from delphix.api.gateway.model.virtualization_storage_summary_report_response import VirtualizationStorageSummaryReportResponse
from delphix.api.gateway.model.virtualization_task import VirtualizationTask
from delphix.api.gateway.model.virtualization_task_event import VirtualizationTaskEvent



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.cleanup_execution_response import CleanupExecutionResponse
from delphix.api.gateway.model.execution import Execution
from delphix.api.gateway.model.execution_cancel_parameters import ExecutionCancelParameters
from delphix.api.gateway.model.execution_log import ExecutionLog
from delphix.api.gateway.model.list_execution_events_response import ListExecutionEventsResponse
from delphix.api.gateway.model.list_executions_response import ListExecutionsResponse
from delphix.api.gateway.model.restart_execution_response import RestartExecutionResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_execution_events_response import SearchExecutionEventsResponse
from delphix.api.gateway.model.search_executions_response import SearchExecutionsResponse


class ExecutionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __cancel_execution(
            self,
            execution_id,
            **kwargs
        ):
            """Cancel an Execution.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.cancel_execution(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                execution_cancel_parameters (ExecutionCancelParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.cancel_execution = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}/cancel',
                'operation_id': 'cancel_execution',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                    'execution_cancel_parameters',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'execution_id',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                    'execution_cancel_parameters':
                        (ExecutionCancelParameters,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                },
                'location_map': {
                    'execution_id': 'path',
                    'execution_cancel_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__cancel_execution
        )

        def __cleanup_execution(
            self,
            execution_id,
            **kwargs
        ):
            """Cleanup an Execution (Hyperscale only).  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.cleanup_execution(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CleanupExecutionResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.cleanup_execution = _Endpoint(
            settings={
                'response_type': (CleanupExecutionResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}/cleanup',
                'operation_id': 'cleanup_execution',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'execution_id',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                },
                'location_map': {
                    'execution_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__cleanup_execution
        )

        def __get_execution_by_id(
            self,
            execution_id,
            **kwargs
        ):
            """Retrieve an Execution by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_execution_by_id(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Execution
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.get_execution_by_id = _Endpoint(
            settings={
                'response_type': (Execution,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}',
                'operation_id': 'get_execution_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'execution_id',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                },
                'location_map': {
                    'execution_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_execution_by_id
        )

        def __get_execution_events(
            self,
            execution_id,
            **kwargs
        ):
            """Retrieve the list of events for a masking execution.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_execution_events(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListExecutionEventsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.get_execution_events = _Endpoint(
            settings={
                'response_type': (ListExecutionEventsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}/events',
                'operation_id': 'get_execution_events',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'execution_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "EXECUTION_ID": "execution_id",
                        "-EXECUTION_ID": "-execution_id",
                        "EVENT_TYPE": "event_type",
                        "-EVENT_TYPE": "-event_type",
                        "SEVERITY": "severity",
                        "-SEVERITY": "-severity",
                        "CAUSE": "cause",
                        "-CAUSE": "-cause",
                        "COUNT": "count",
                        "-COUNT": "-count",
                        "TIMESTAMP": "timestamp",
                        "-TIMESTAMP": "-timestamp",
                        "MASKED_OBJECT_NAME": "masked_object_name",
                        "-MASKED_OBJECT_NAME": "-masked_object_name",
                        "BYTES_PROCESSED": "bytes_processed",
                        "-BYTES_PROCESSED": "-bytes_processed",
                        "ALGORITHM_NAME": "algorithm_name",
                        "-ALGORITHM_NAME": "-algorithm_name",
                        "EXCEPTION_TYPE": "exception_type",
                        "-EXCEPTION_TYPE": "-exception_type",
                        "EXCEPTION_DETAIL": "exception_detail",
                        "-EXCEPTION_DETAIL": "-exception_detail"
                    },
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'execution_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_execution_events
        )

        def __get_execution_log(
            self,
            execution_id,
            **kwargs
        ):
            """Retrieve the masking execution log.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_execution_log(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ExecutionLog
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.get_execution_log = _Endpoint(
            settings={
                'response_type': (ExecutionLog,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}/log',
                'operation_id': 'get_execution_log',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'execution_id',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                },
                'location_map': {
                    'execution_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_execution_log
        )

        def __get_executions(
            self,
            **kwargs
        ):
            """Retrieve the list of masking executions.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_executions(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListExecutionsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_executions = _Endpoint(
            settings={
                'response_type': (ListExecutionsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions',
                'operation_id': 'get_executions',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "ENGINE_ID": "engine_id",
                        "-ENGINE_ID": "-engine_id",
                        "ENGINE_NAME": "engine_name",
                        "-ENGINE_NAME": "-engine_name",
                        "MASKING_JOB_ID": "masking_job_id",
                        "-MASKING_JOB_ID": "-masking_job_id",
                        "MASKING_JOB_NAME": "masking_job_name",
                        "-MASKING_JOB_NAME": "-masking_job_name",
                        "SOURCE_CONNECTOR_ID": "source_connector_id",
                        "-SOURCE_CONNECTOR_ID": "-source_connector_id",
                        "TARGET_CONNECTOR_ID": "target_connector_id",
                        "-TARGET_CONNECTOR_ID": "-target_connector_id",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "ROWS_MASKED": "rows_masked",
                        "-ROWS_MASKED": "-rows_masked",
                        "ROWS_TOTAL": "rows_total",
                        "-ROWS_TOTAL": "-rows_total",
                        "BYTES_PROCESSED": "bytes_processed",
                        "-BYTES_PROCESSED": "-bytes_processed",
                        "BYTES_TOTAL": "bytes_total",
                        "-BYTES_TOTAL": "-bytes_total",
                        "START_TIME": "start_time",
                        "-START_TIME": "-start_time",
                        "END_TIME": "end_time",
                        "-END_TIME": "-end_time",
                        "SUBMIT_TIME": "submit_time",
                        "-SUBMIT_TIME": "-submit_time"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_executions
        )

        def __restart_execution(
            self,
            execution_id,
            **kwargs
        ):
            """Restart an Execution (Hyperscale only).  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.restart_execution(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RestartExecutionResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.restart_execution = _Endpoint(
            settings={
                'response_type': (RestartExecutionResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}/restart',
                'operation_id': 'restart_execution',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'execution_id',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                },
                'location_map': {
                    'execution_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__restart_execution
        )

        def __search_execution_events(
            self,
            execution_id,
            **kwargs
        ):
            """Search masking executions events.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_execution_events(execution_id, async_req=True)
            >>> result = thread.get()

            Args:
                execution_id (str): The ID of the Execution.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchExecutionEventsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['execution_id'] = \
                execution_id
            return self.call_with_http_info(**kwargs)

        self.search_execution_events = _Endpoint(
            settings={
                'response_type': (SearchExecutionEventsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/{executionId}/events/search',
                'operation_id': 'search_execution_events',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'execution_id',
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [
                    'execution_id',
                ],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'execution_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('execution_id',): {

                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "EXECUTION_ID": "execution_id",
                        "-EXECUTION_ID": "-execution_id",
                        "EVENT_TYPE": "event_type",
                        "-EVENT_TYPE": "-event_type",
                        "SEVERITY": "severity",
                        "-SEVERITY": "-severity",
                        "CAUSE": "cause",
                        "-CAUSE": "-cause",
                        "COUNT": "count",
                        "-COUNT": "-count",
                        "TIMESTAMP": "timestamp",
                        "-TIMESTAMP": "-timestamp",
                        "MASKED_OBJECT_NAME": "masked_object_name",
                        "-MASKED_OBJECT_NAME": "-masked_object_name",
                        "BYTES_PROCESSED": "bytes_processed",
                        "-BYTES_PROCESSED": "-bytes_processed",
                        "ALGORITHM_NAME": "algorithm_name",
                        "-ALGORITHM_NAME": "-algorithm_name",
                        "EXCEPTION_TYPE": "exception_type",
                        "-EXCEPTION_TYPE": "-exception_type",
                        "EXCEPTION_DETAIL": "exception_detail",
                        "-EXCEPTION_DETAIL": "-exception_detail"
                    },
                },
                'openapi_types': {
                    'execution_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'execution_id': 'executionId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'execution_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_execution_events
        )

        def __search_executions(
            self,
            **kwargs
        ):
            """Search masking executions.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_executions(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchExecutionsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_executions = _Endpoint(
            settings={
                'response_type': (SearchExecutionsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/executions/search',
                'operation_id': 'search_executions',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "ENGINE_ID": "engine_id",
                        "-ENGINE_ID": "-engine_id",
                        "ENGINE_NAME": "engine_name",
                        "-ENGINE_NAME": "-engine_name",
                        "MASKING_JOB_ID": "masking_job_id",
                        "-MASKING_JOB_ID": "-masking_job_id",
                        "MASKING_JOB_NAME": "masking_job_name",
                        "-MASKING_JOB_NAME": "-masking_job_name",
                        "SOURCE_CONNECTOR_ID": "source_connector_id",
                        "-SOURCE_CONNECTOR_ID": "-source_connector_id",
                        "TARGET_CONNECTOR_ID": "target_connector_id",
                        "-TARGET_CONNECTOR_ID": "-target_connector_id",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "ROWS_MASKED": "rows_masked",
                        "-ROWS_MASKED": "-rows_masked",
                        "ROWS_TOTAL": "rows_total",
                        "-ROWS_TOTAL": "-rows_total",
                        "BYTES_PROCESSED": "bytes_processed",
                        "-BYTES_PROCESSED": "-bytes_processed",
                        "BYTES_TOTAL": "bytes_total",
                        "-BYTES_TOTAL": "-bytes_total",
                        "START_TIME": "start_time",
                        "-START_TIME": "-start_time",
                        "END_TIME": "end_time",
                        "-END_TIME": "-end_time",
                        "SUBMIT_TIME": "submit_time",
                        "-SUBMIT_TIME": "-submit_time"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_executions
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.replication_api import ReplicationApi  # noqa: E501


class TestReplicationApi(unittest.TestCase):
    """ReplicationApi unit test stubs"""

    def setUp(self):
        self.api = ReplicationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_replication_profile_tags(self):
        """Test case for create_replication_profile_tags

        Create tags for a ReplicationProfile.  # noqa: E501
        """
        pass

    def test_delete_repliation_profile_tags(self):
        """Test case for delete_repliation_profile_tags

        Delete tags for a ReplicationProfile.  # noqa: E501
        """
        pass

    def test_disable_tag_replication(self):
        """Test case for disable_tag_replication

        Disable tag replication for given ReplicationProfile.  # noqa: E501
        """
        pass

    def test_enable_tag_replication(self):
        """Test case for enable_tag_replication

        Enable tag replication for given ReplicationProfile.  # noqa: E501
        """
        pass

    def test_get_replication_profile_by_id(self):
        """Test case for get_replication_profile_by_id

        Get a ReplicationProfile by ID.  # noqa: E501
        """
        pass

    def test_get_replication_profile_tags(self):
        """Test case for get_replication_profile_tags

        Get tags for a ReplicationProfile.  # noqa: E501
        """
        pass

    def test_get_replication_profiles(self):
        """Test case for get_replication_profiles

        List all ReplicationProfiles.  # noqa: E501
        """
        pass

    def test_search_replication_profiles(self):
        """Test case for search_replication_profiles

        Search for ReplicationProfiles.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.kerberos_config_api import KerberosConfigApi  # noqa: E501


class TestKerberosConfigApi(unittest.TestCase):
    """KerberosConfigApi unit test stubs"""

    def setUp(self):
        self.api = KerberosConfigApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_kerberos_config_by_id(self):
        """Test case for get_kerberos_config_by_id

        Get a kerberos config by ID or Name.  # noqa: E501
        """
        pass

    def test_list_kerberos_configs(self):
        """Test case for list_kerberos_configs

        List all kerberos configs.  # noqa: E501
        """
        pass

    def test_search_kerberos_configs(self):
        """Test case for search_kerberos_configs

        Search for Kerberos Configs.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.management_api import ManagementApi  # noqa: E501


class TestManagementApi(unittest.TestCase):
    """ManagementApi unit test stubs"""

    def setUp(self):
        self.api = ManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_engine_tags(self):
        """Test case for create_engine_tags

        Create tags for an Engine.  # noqa: E501
        """
        pass

    def test_create_hashicorp_vault(self):
        """Test case for create_hashicorp_vault

        Configure a new Hashicorp Vault  # noqa: E501
        """
        pass

    def test_create_hashicorp_vault_tags(self):
        """Test case for create_hashicorp_vault_tags

        Create tags for a Hashicorp vault.  # noqa: E501
        """
        pass

    def test_delete_engine_tags(self):
        """Test case for delete_engine_tags

        Delete tags for an Engine.  # noqa: E501
        """
        pass

    def test_delete_hashicorp_vault(self):
        """Test case for delete_hashicorp_vault

        Delete a Hashicorp vault by id  # noqa: E501
        """
        pass

    def test_delete_hashicorp_vault_tag(self):
        """Test case for delete_hashicorp_vault_tag

        Delete tags for a Hashicorp vault.  # noqa: E501
        """
        pass

    def test_get_api_classification(self):
        """Test case for get_api_classification

        Get api classification.  # noqa: E501
        """
        pass

    def test_get_engine_tags(self):
        """Test case for get_engine_tags

        Get tags for a Engine.  # noqa: E501
        """
        pass

    def test_get_hashicorp_vault(self):
        """Test case for get_hashicorp_vault

        Get a Hashicorp vault by id  # noqa: E501
        """
        pass

    def test_get_hashicorp_vault_tags(self):
        """Test case for get_hashicorp_vault_tags

        Get tags for a Hashicorp vault.  # noqa: E501
        """
        pass

    def test_get_hashicorp_vaults(self):
        """Test case for get_hashicorp_vaults

        Returns a list of configured Hashicorp vaults.  # noqa: E501
        """
        pass

    def test_get_ldap_config(self):
        """Test case for get_ldap_config

        Returns the LDAP configuration  # noqa: E501
        """
        pass

    def test_get_metadata_database(self):
        """Test case for get_metadata_database

        Returns configuration information about the metadata database which stores the product data.  # noqa: E501
        """
        pass

    def test_get_product_registration_key(self):
        """Test case for get_product_registration_key

        Generates and returns a public key that can be used to register the product.  # noqa: E501
        """
        pass

    def test_get_proxy_configuration(self):
        """Test case for get_proxy_configuration

        Returns the current Proxy configuration.  # noqa: E501
        """
        pass

    def test_get_registered_engine(self):
        """Test case for get_registered_engine

        Returns a registered engine by ID.  # noqa: E501
        """
        pass

    def test_get_registered_engines(self):
        """Test case for get_registered_engines

        Returns a list of registered engines.  # noqa: E501
        """
        pass

    def test_get_saml_config(self):
        """Test case for get_saml_config

        Returns the SAML configuration  # noqa: E501
        """
        pass

    def test_get_smtp_config(self):
        """Test case for get_smtp_config

        Returns the SMTP configuration  # noqa: E501
        """
        pass

    def test_list_properties(self):
        """Test case for list_properties

        Get global properties.  # noqa: E501
        """
        pass

    def test_register_engine(self):
        """Test case for register_engine

        Register an engine.  # noqa: E501
        """
        pass

    def test_register_product_offline(self):
        """Test case for register_product_offline

        Registers the product using a manually generated payload.  # noqa: E501
        """
        pass

    def test_register_product_online(self):
        """Test case for register_product_online

        Registers the product using the provided credentials.  # noqa: E501
        """
        pass

    def test_search_engines(self):
        """Test case for search_engines

        Search for engines.  # noqa: E501
        """
        pass

    def test_search_hashicorp_vaults(self):
        """Test case for search_hashicorp_vaults

        Search for configured Hashicorp vaults.  # noqa: E501
        """
        pass

    def test_unregister_engine(self):
        """Test case for unregister_engine

        Unregister an engine.  # noqa: E501
        """
        pass

    def test_update_api_classification(self):
        """Test case for update_api_classification

        Update the api classification to new version.  # noqa: E501
        """
        pass

    def test_update_ldap_config(self):
        """Test case for update_ldap_config

        Update LDAP Config.  # noqa: E501
        """
        pass

    def test_update_properties(self):
        """Test case for update_properties

        Update value of predefined properties.  # noqa: E501
        """
        pass

    def test_update_proxy_configuration(self):
        """Test case for update_proxy_configuration

        Update Proxy configuration.  # noqa: E501
        """
        pass

    def test_update_registered_engine(self):
        """Test case for update_registered_engine

        Update a registered engine.  # noqa: E501
        """
        pass

    def test_update_registered_engine_partial(self):
        """Test case for update_registered_engine_partial

        Update a registered engine.  # noqa: E501
        """
        pass

    def test_update_saml_config(self):
        """Test case for update_saml_config

        Update SAML Config.  # noqa: E501
        """
        pass

    def test_update_smtp_config(self):
        """Test case for update_smtp_config

        Update SMTP Config.  # noqa: E501
        """
        pass

    def test_validate_java_path(self):
        """Test case for validate_java_path

        Validate java path for the remote host machine.  # noqa: E501
        """
        pass

    def test_validate_ldap_config(self):
        """Test case for validate_ldap_config

        Validate LDAP Config. Without username/password, DCT performs an anonymous bind against the LDAP server. If credentials are provided DCT validates that authentication and mapping of optional properties are actually working with provided credentials. LDAP search is only validated if search attributes are set.  # noqa: E501
        """
        pass

    def test_validate_smtp_config(self):
        """Test case for validate_smtp_config

        Validate SMTP Config.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.toolkits_api import ToolkitsApi  # noqa: E501


class TestToolkitsApi(unittest.TestCase):
    """ToolkitsApi unit test stubs"""

    def setUp(self):
        self.api = ToolkitsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_toolkit_tags(self):
        """Test case for create_toolkit_tags

        Create tags for a toolkit.  # noqa: E501
        """
        pass

    def test_delete_toolkit_tags(self):
        """Test case for delete_toolkit_tags

        Delete tags for a Toolkit.  # noqa: E501
        """
        pass

    def test_get_toolkit_by_id(self):
        """Test case for get_toolkit_by_id

        Get Toolkit by ID.  # noqa: E501
        """
        pass

    def test_get_toolkit_tags(self):
        """Test case for get_toolkit_tags

        Get tags for a Toolkit.  # noqa: E501
        """
        pass

    def test_get_toolkits(self):
        """Test case for get_toolkits

        List all toolkits.  # noqa: E501
        """
        pass

    def test_search_toolkits(self):
        """Test case for search_toolkits

        Search for toolkits.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.vdbs_api import VDBsApi  # noqa: E501


class TestVDBsApi(unittest.TestCase):
    """VDBsApi unit test stubs"""

    def setUp(self):
        self.api = VDBsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_vdb_tags(self):
        """Test case for create_vdb_tags

        Create tags for a VDB.  # noqa: E501
        """
        pass

    def test_delete_vdb(self):
        """Test case for delete_vdb

        Delete a VDB.  # noqa: E501
        """
        pass

    def test_delete_vdb_tags(self):
        """Test case for delete_vdb_tags

        Delete tags for a VDB.  # noqa: E501
        """
        pass

    def test_disable_vdb(self):
        """Test case for disable_vdb

        Disable a VDB.  # noqa: E501
        """
        pass

    def test_enable_vdb(self):
        """Test case for enable_vdb

        Enable a VDB.  # noqa: E501
        """
        pass

    def test_get_bookmarks_by_vdb(self):
        """Test case for get_bookmarks_by_vdb

        List Bookmarks compatible with this VDB.  # noqa: E501
        """
        pass

    def test_get_tags_vdb(self):
        """Test case for get_tags_vdb

        Get tags for a VDB.  # noqa: E501
        """
        pass

    def test_get_vdb_by_id(self):
        """Test case for get_vdb_by_id

        Get a VDB by ID.  # noqa: E501
        """
        pass

    def test_get_vdb_snapshots(self):
        """Test case for get_vdb_snapshots

        List Snapshots for a VDB.  # noqa: E501
        """
        pass

    def test_get_vdbs(self):
        """Test case for get_vdbs

        List all vdbs.  # noqa: E501
        """
        pass

    def test_lock_vdb(self):
        """Test case for lock_vdb

        Lock a VDB.  # noqa: E501
        """
        pass

    def test_provision_vdb_by_location(self):
        """Test case for provision_vdb_by_location

        Provision a new VDB by location.  # noqa: E501
        """
        pass

    def test_provision_vdb_by_location_defaults(self):
        """Test case for provision_vdb_by_location_defaults

        Get default provision parameters for provisioning a new VDB by location.  # noqa: E501
        """
        pass

    def test_provision_vdb_by_snapshot(self):
        """Test case for provision_vdb_by_snapshot

        Provision a new VDB by snapshot.  # noqa: E501
        """
        pass

    def test_provision_vdb_by_snapshot_defaults(self):
        """Test case for provision_vdb_by_snapshot_defaults

        Get default provision parameters for provisioning a new VDB by snapshot.  # noqa: E501
        """
        pass

    def test_provision_vdb_by_timestamp(self):
        """Test case for provision_vdb_by_timestamp

        Provision a new VDB by timestamp.  # noqa: E501
        """
        pass

    def test_provision_vdb_by_timestamp_defaults(self):
        """Test case for provision_vdb_by_timestamp_defaults

        Get default provision parameters for provisioning a new VDB by timestamp.  # noqa: E501
        """
        pass

    def test_provision_vdb_from_bookmark(self):
        """Test case for provision_vdb_from_bookmark

        Provision a new VDB from a bookmark with a single VDB.  # noqa: E501
        """
        pass

    def test_provision_vdb_from_bookmark_defaults(self):
        """Test case for provision_vdb_from_bookmark_defaults

        Get default provision parameters for provisioning a new VDB from a bookmark.  # noqa: E501
        """
        pass

    def test_refresh_vdb_by_location(self):
        """Test case for refresh_vdb_by_location

        Refresh a VDB by location.  # noqa: E501
        """
        pass

    def test_refresh_vdb_by_snapshot(self):
        """Test case for refresh_vdb_by_snapshot

        Refresh a VDB by snapshot.  # noqa: E501
        """
        pass

    def test_refresh_vdb_by_timestamp(self):
        """Test case for refresh_vdb_by_timestamp

        Refresh a VDB by timestamp.  # noqa: E501
        """
        pass

    def test_refresh_vdb_from_bookmark(self):
        """Test case for refresh_vdb_from_bookmark

        Refresh a VDB from bookmark with a single VDB.  # noqa: E501
        """
        pass

    def test_rollback_vdb_by_snapshot(self):
        """Test case for rollback_vdb_by_snapshot

        Rollback a VDB by snapshot.  # noqa: E501
        """
        pass

    def test_rollback_vdb_by_timestamp(self):
        """Test case for rollback_vdb_by_timestamp

        Rollback a VDB by timestamp.  # noqa: E501
        """
        pass

    def test_rollback_vdb_from_bookmark(self):
        """Test case for rollback_vdb_from_bookmark

        Rollback a VDB from a bookmark with only the same VDB.  # noqa: E501
        """
        pass

    def test_search_bookmarks_by_vdb(self):
        """Test case for search_bookmarks_by_vdb

        Search Bookmarks compatible with this VDB.  # noqa: E501
        """
        pass

    def test_search_vdbs(self):
        """Test case for search_vdbs

        Search for VDBs.  # noqa: E501
        """
        pass

    def test_snapshot_vdb(self):
        """Test case for snapshot_vdb

        Snapshot a VDB.  # noqa: E501
        """
        pass

    def test_start_vdb(self):
        """Test case for start_vdb

        Start a VDB.  # noqa: E501
        """
        pass

    def test_stop_vdb(self):
        """Test case for stop_vdb

        Stop a VDB.  # noqa: E501
        """
        pass

    def test_switch_timeflow(self):
        """Test case for switch_timeflow

        Switches the current timeflow of a VDB.  # noqa: E501
        """
        pass

    def test_unlock_vdb(self):
        """Test case for unlock_vdb

        Unlock a VDB.  # noqa: E501
        """
        pass

    def test_update_vdb_by_id(self):
        """Test case for update_vdb_by_id

        Update values of a VDB  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
